var a00250 =
[
    [ "Color", "a00250.html#af0d8129bf1a819c468c6edcb13b5203b", null ],
    [ "ConstEdgeIter", "a00250.html#aca72b40b26d4c76dfaec5e4191bdaa31", null ],
    [ "ConstFaceEdgeIter", "a00250.html#a5e15960d27e6d40646260109f5910b5b", null ],
    [ "ConstFaceFaceIter", "a00250.html#af081cbe692a0563c1ce08735f4b3491e", null ],
    [ "ConstFaceHalfedgeIter", "a00250.html#a1b0729c26d7cf8f123c344a3b81d353c", null ],
    [ "ConstFaceIter", "a00250.html#a0a371650bb71152018ea1f3f570b465b", null ],
    [ "ConstFaceVertexIter", "a00250.html#a23b20f8208bae0aa1b344cac48c1f635", null ],
    [ "ConstHalfedgeIter", "a00250.html#a85c57baa38e7e3d07bd7f3c7f194b354", null ],
    [ "ConstVertexEdgeIter", "a00250.html#a9ccd0ce4fff127b13eb80fafefda0d0a", null ],
    [ "ConstVertexFaceIter", "a00250.html#a61167f0a130e599b909cc8629a6dca2a", null ],
    [ "ConstVertexIHalfedgeIter", "a00250.html#a7221db878118b37611454a13f1754a08", null ],
    [ "ConstVertexIter", "a00250.html#acbad7fb3cfb4bad77153b9a8530a402f", null ],
    [ "ConstVertexOHalfedgeIter", "a00250.html#acf4b52db4b0198a91a02c06003623bfb", null ],
    [ "ConstVertexVertexIter", "a00250.html#a17a73f876343905c8b37b947e9152ac8", null ],
    [ "Edge", "a00250.html#ab2ccdc42b7b25cf35915d3639fc461b2", null ],
    [ "EdgeHandle", "a00250.html#a1e3309b66b4cb3bf22b6229f20375ef2", null ],
    [ "EdgeIter", "a00250.html#ac5250dba0f527b19bfa665a288b5d63d", null ],
    [ "Face", "a00250.html#a71e1e8eaabeb24eca04237931b4bea26", null ],
    [ "FaceEdgeIter", "a00250.html#a04a30000943150f98db373a3317760af", null ],
    [ "FaceFaceIter", "a00250.html#a98618ca3fd3eec347bb5b02410a5e1e6", null ],
    [ "FaceHalfedgeIter", "a00250.html#aeca99c6cd952038e80b37c848035af73", null ],
    [ "FaceHandle", "a00250.html#ab4c0e43573d85661542b22cb4f4a1d11", null ],
    [ "FaceIter", "a00250.html#a34402ff0bd674fbad2685df22eecde64", null ],
    [ "FaceVertexIter", "a00250.html#a3c65ec045ac0126b3ea7264cee26aa1b", null ],
    [ "Halfedge", "a00250.html#a249b0c195a81eeab341f7f73089d157e", null ],
    [ "HalfedgeHandle", "a00250.html#ac364b18ba6ed17e4e6a6551787b2e2a3", null ],
    [ "HalfedgeIter", "a00250.html#ae40d2dfe0d226e49d869481bbd40a911", null ],
    [ "Normal", "a00250.html#a3570fd132d1ac589b380485cf59c9e0b", null ],
    [ "Point", "a00250.html#aed10fb4dfb536b53a5e20c8f2442eadf", null ],
    [ "Scalar", "a00250.html#a15372f27edf521d8e9028e2abccae342", null ],
    [ "TexCoord1D", "a00250.html#af6526fbc3e7f3a1e98a5543b9563b021", null ],
    [ "TexCoord2D", "a00250.html#a4ae59536e97b43444c4f1622c645ebaf", null ],
    [ "TexCoord3D", "a00250.html#a5ec24476d2513efe71ddd1255a2ca444", null ],
    [ "This", "a00250.html#aee8e212a032787407e4a543031840063", null ],
    [ "Vertex", "a00250.html#a03e6fd1a2fc91d4144374fd28dfbecee", null ],
    [ "VertexEdgeIter", "a00250.html#a68dd0d2773f837cbfb525d7208dedde0", null ],
    [ "VertexFaceIter", "a00250.html#a1ebe8b94ca30db3af44c809ab3ee7247", null ],
    [ "VertexHandle", "a00250.html#a0fc18e13d70825938274e3faf7b55e01", null ],
    [ "VertexIHalfedgeIter", "a00250.html#a437621f3901a93d0ebf8cdceac8e2939", null ],
    [ "VertexIter", "a00250.html#afb18d53e36e53e024c8506cd3c961096", null ],
    [ "VertexOHalfedgeIter", "a00250.html#a6549eda743520c8a7aa3dfe6a37b2468", null ],
    [ "VertexVertexIter", "a00250.html#adc7d422e2ce13141e8291f7d29f7ecef", null ],
    [ "IsPolyMesh", "a00250.html#a5d0ff00a35aa4b3ebfa554441def1334a728dfa21d7d5250680882d1b5fed00d1", null ],
    [ "IsTriMesh", "a00250.html#ab049a82d0fafc6b5e81936c8debc9952a1b4d6819901e11a6626d36e341adef21", null ],
    [ "PolyMeshT", "a00250.html#a2fdf6fd8d438200ff0c885b828affca4", null ],
    [ "~PolyMeshT", "a00250.html#a9c9a45cb7c87a1aaed9577210a68e527", null ],
    [ "add_vertex", "a00250.html#ac0577d7120881533e6e3af635382ba82", null ],
    [ "add_vertex_dirty", "a00250.html#ad2b584d9b8cf0f168be8d536fc593ec0", null ],
    [ "calc_dihedral_angle", "a00250.html#a410f38155ec12c4409579f8346b4009c", null ],
    [ "calc_dihedral_angle", "a00250.html#a0c8076b4547614001d7f49960f8dd1ed", null ],
    [ "calc_dihedral_angle_fast", "a00250.html#a49dd0f24137854f97530779c58f1a964", null ],
    [ "calc_dihedral_angle_fast", "a00250.html#ab02b7b6311a48b3b1dca15ca33bf55af", null ],
    [ "calc_edge_length", "a00250.html#a822dab13832e6151dc6c83e88d82625d", null ],
    [ "calc_edge_length", "a00250.html#aece958e03921a6cf39045b8b1013e448", null ],
    [ "calc_edge_sqr_length", "a00250.html#a595150124f47261e85bed7daef94af9f", null ],
    [ "calc_edge_sqr_length", "a00250.html#a0da8b1b2b463dabd292311c9b834f6a9", null ],
    [ "calc_edge_vector", "a00250.html#a090d5252328e5fbd7f10e2cc3576d2eb", null ],
    [ "calc_edge_vector", "a00250.html#a2b45bfb6c89627b22a1ae33be996ec9f", null ],
    [ "calc_edge_vector", "a00250.html#a3ce28ba8fef4acb4e97c380be47ef240", null ],
    [ "calc_edge_vector", "a00250.html#af183231a6d5eb220370c017e40f3adb1", null ],
    [ "calc_face_centroid", "a00250.html#a4d493c0b39c20eef9e169bce81e243dc", null ],
    [ "calc_face_centroid", "a00250.html#a9fc738c69147f4fa18cba94cd0d84523", null ],
    [ "calc_face_normal", "a00250.html#aad3b0a3001c7e44714e16442b78583af", null ],
    [ "calc_face_normal", "a00250.html#af2785fb696363e3b4a65df8319f06dd6", null ],
    [ "calc_halfedge_normal", "a00250.html#a9c1231e5c26af1cdec5b0745b6727d4b", null ],
    [ "calc_sector_angle", "a00250.html#a458cb0e3630ed058b40df038ee65a611", null ],
    [ "calc_sector_area", "a00250.html#ab72758b5395b2b489f12f82d242531ce", null ],
    [ "calc_sector_normal", "a00250.html#a2996b1f2d1a63073b837e5ad438a1832", null ],
    [ "calc_sector_vectors", "a00250.html#a1fb01f73d2eec4de5ccaf47fe22b01b1", null ],
    [ "calc_vertex_normal", "a00250.html#a05f9cf93cfc2d00e9060ee04aba64cde", null ],
    [ "calc_vertex_normal_correct", "a00250.html#a268f9ebdf96e451c2cbf28fe252b8eee", null ],
    [ "calc_vertex_normal_fast", "a00250.html#adb4f197611a4ceba81e7262ccb3e57d8", null ],
    [ "calc_vertex_normal_loop", "a00250.html#a1e35bd2564bb83b080dafea72bc99e86", null ],
    [ "find_feature_edges", "a00250.html#a5a52366a97b3c87ab3473c476f221e22", null ],
    [ "is_estimated_feature_edge", "a00250.html#a2f6f5dd7a243ce8b34233361f17131ff", null ],
    [ "new_vertex", "a00250.html#aee07d968ddfbb6376a7f7712ae1a73c4", null ],
    [ "new_vertex", "a00250.html#a77d36a90d4c207845cf1478aec56c283", null ],
    [ "new_vertex_dirty", "a00250.html#a8787adda36a734b33fa578f9c50bb2f3", null ],
    [ "split", "a00250.html#af0bd67ac6c4c3fa8707191dcf28b7649", null ],
    [ "split", "a00250.html#a48712f39ad55c72ab48bf1127b6113bf", null ],
    [ "split", "a00250.html#ac198e4c43d5baf73b85557eaa48cc722", null ],
    [ "split", "a00250.html#adf9763c2328f9c70113da70f8fdc60c4", null ],
    [ "update_face_normals", "a00250.html#a5677ec057717fece1bc3c7abbf93cbdf", null ],
    [ "update_halfedge_normals", "a00250.html#a58045f9fafc6239077c747afdd8f852d", null ],
    [ "update_normal", "a00250.html#ab7b40ea47b87d63d3f7a4a448b2a5a8d", null ],
    [ "update_normal", "a00250.html#ac98934e64388f212e03a66b39d0ee137", null ],
    [ "update_normal", "a00250.html#a8f33200ba959d2d68e62d0cdf0afe322", null ],
    [ "update_normals", "a00250.html#a601f21014e50bd5a2243b0e4849c9c14", null ],
    [ "update_vertex_normals", "a00250.html#acbf60ccc42cb484ba2911bda8277551c", null ]
];